@@ -2,17 +2,17 @@ from .and_ import and_
 
 
 def nand(a=True, b=True, c=True, d=True, e=True, f=True, g=True, h=True):
-  """Checks if any value is false. `📘`_
+  """Checks if any value is False. `📘`_
 
   - a: 1st boolean
   - b: 2nd boolean
   - ...
 
   Example:
-    >>> nand(true, false)             == true
-    >>> nand(true, true)              == false
-    >>> nand(true, true, false, true) == true
-    >>> nand(true, true, true, true)  == false
+    >>> nand(True, False)             == True
+    >>> nand(True, True)              == False
+    >>> nand(True, True, False, True) == True
+    >>> nand(True, True, True, True)  == False
 
   .. _📘:
     https://github.com/python3f/extra-boolean/wiki/nand
